==> blesta-5.10.2.zip: blesta/components/gateways/merchant/authorize_net_acceptjs/language/tr_tr/authorize_net_acceptjs.php <==
<?php
/**
 * Authorize Net Acceptjs
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AuthorizeNetAcceptjs.field_expiration'] = 'Son Kullanma Tarihi';
$lang['AuthorizeNetAcceptjs.field_security'] = 'Güvenlik Kodu';
$lang['AuthorizeNetAcceptjs.field_number'] = 'Sayı';
$lang['AuthorizeNetAcceptjs.description'] = 'Güvenli ödeme verilerini doğrudan Authorize.net\'e gönderin. Accept.js ödeme verilerini yakalar ve doğrudan Authorize.net\'e gönderir.';
$lang['AuthorizeNetAcceptjs.!error.sandbox.valid'] = 'Sandbox verilmişse "true" olarak ayarlanmalıdır.';
$lang['AuthorizeNetAcceptjs.charge_description'] = '1$s için ücretlendirme';
$lang['AuthorizeNetAcceptjs.charge_description_default'] = 'Belirtilen miktar için ücretlendirme';
$lang['AuthorizeNetAcceptjs.sandbox_note'] = 'Bu seçeneğin etkinleştirilmesi, işlemleri Authorize.Net Sandbox ortamına gönderir. Bu seçeneği yalnızca bir Authorize.Net Sandbox hesabı ile test yapıyorsanız etkinleştirin.';
$lang['AuthorizeNetAcceptjs.sandbox'] = 'Sandbox';
$lang['AuthorizeNetAcceptjs.transaction_key'] = 'İşlem Anahtarı';
$lang['AuthorizeNetAcceptjs.!error.login_id.valid'] = 'Verilen Oturum Açma Kimliği kullanılarak Authorize.net API\'sine bağlanılamıyor.';
$lang['AuthorizeNetAcceptjs.login_id'] = 'Giriş Kimliği';
$lang['AuthorizeNetAcceptjs.name'] = 'Authorize.Net Accept.js';
$lang['AuthorizeNetAcceptjs.!error.login_id.empty'] = 'Lütfen bir Oturum Açma Kimliği girin.';
$lang['AuthorizeNetAcceptjs.!error.transaction_key.empty'] = 'Lütfen bir İşlem Anahtarı girin.';
$lang['AuthorizeNetAcceptjs.!error.auth'] = 'Ağ geçidi kimlik doğrulaması yapamadı.';

==> blesta-5.11.4.zip: blesta/components/gateways/merchant/authorize_net_acceptjs/language/tr_tr/authorize_net_acceptjs.php <==
<?php
/**
 * Authorize Net Acceptjs
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AuthorizeNetAcceptjs.field_expiration'] = 'Son Kullanma Tarihi';
$lang['AuthorizeNetAcceptjs.field_security'] = 'Güvenlik Kodu';
$lang['AuthorizeNetAcceptjs.field_number'] = 'Sayı';
$lang['AuthorizeNetAcceptjs.description'] = 'Güvenli ödeme verilerini doğrudan Authorize.net\'e gönderin. Accept.js ödeme verilerini yakalar ve doğrudan Authorize.net\'e gönderir.';
$lang['AuthorizeNetAcceptjs.!error.sandbox.valid'] = 'Sandbox verilmişse "true" olarak ayarlanmalıdır.';
$lang['AuthorizeNetAcceptjs.charge_description_default'] = 'Belirtilen miktar için ücretlendirme';
$lang['AuthorizeNetAcceptjs.sandbox_note'] = 'Bu seçeneğin etkinleştirilmesi, işlemleri Authorize.Net Sandbox ortamına gönderir. Bu seçeneği yalnızca bir Authorize.Net Sandbox hesabı ile test yapıyorsanız etkinleştirin.';
$lang['AuthorizeNetAcceptjs.sandbox'] = 'Sandbox';
$lang['AuthorizeNetAcceptjs.transaction_key'] = 'İşlem Anahtarı';
$lang['AuthorizeNetAcceptjs.!error.login_id.valid'] = 'Verilen Oturum Açma Kimliği kullanılarak Authorize.net API\'sine bağlanılamıyor.';
$lang['AuthorizeNetAcceptjs.login_id'] = 'Giriş Kimliği';
$lang['AuthorizeNetAcceptjs.name'] = 'Authorize.Net Accept.js';
$lang['AuthorizeNetAcceptjs.!error.login_id.empty'] = 'Lütfen bir Oturum Açma Kimliği girin.';
$lang['AuthorizeNetAcceptjs.!error.transaction_key.empty'] = 'Lütfen bir İşlem Anahtarı girin.';
$lang['AuthorizeNetAcceptjs.!error.auth'] = 'Ağ geçidi kimlik doğrulaması yapamadı.';
$lang['AuthorizeNetAcceptjs.charge_description'] = 'Ücret %1$s için';
